# Example simulation inputs used in the REXEE paper
This directory contains example simulation inputs used in the simulations reported in our paper, including those for the anthracene and CB7-10 systems. The data here will not be included when the package is installed. Below is the structure of the `data` directory:

```
.
├── CB7-10
│   ├── complex
│   │   ├── complex.gro
│   │   ├── complex.top
│   │   ├── fixed_weight.mdp
│   │   ├── itp_files
│   │   │   ├── 10_GMX.itp
│   │   │   ├── 10atomtypes.itp
│   │   │   └── cucurbit_7_uril_GMX.itp
│   │   ├── params.yaml
│   │   └── weight_updating.mdp
│   └── solvent
│       ├── fixed_weight.mdp
│       ├── ligand.gro
│       ├── ligand.top
│       └── weight_updating.mdp
├── README.md
├── anthracene
│   ├── anthracene.gro
│   ├── anthracene.top
│   ├── fixed_weight.mdp
│   ├── HREX.mdp
│   ├── params.yaml
│   └── weight_updating.mdp
└── instruction.md

5 directories, 20 files
```
Here are some additional notes about the files: 
- For each system, the provided GRO and TOP files were used for all simulations. 
- The file `fixed_weight.mdp` was used for both fixed-weight EE and REXEE simulations for the anthracene system, and for the complex simulation of the CB7-10 system. Similarly, the file `weight_updating.mdp` was used for the weight-updating EE and REXEE simulations for the anthracene system, and for the complex simulation of the CB7-10 system. For the solvent leg of the CB7-10 system, only expanded ensemble simulations were performed. 
- The file `params.yaml` contains REXEE parameters and can be used for both fixed-weight or weight-updating simulations. Relevant parameters were varied between tests for different REXEE simulations reported in the paper. 
- For the CB7-10 system, the directory `itp_files` contains the ITP files referenced in `complex.top`, which is the topology file of the CB7-10 binding complex. 
- The file `instruction.mdp` is just a file generated by the cookiecutter and is irrelevant to the project.
